ap_rep: Check replicate samples

View source: R/ch_functions.R

ap_repR Documentation

Check replicate samples

Description

various plots in one PDF to assess the replicates and overall reproducibility.

Usage

ap_rep(
  x,
  iter = 500,
  shouldpdf = TRUE,
  filename = "replicates.pdf",
  width = 12,
  height = 12,
  useDingbats = FALSE
)

Arguments

x

List with at least two elements, see Deatils for naming and content.

iter

How many times random samples should be iterated.

shouldpdf

Logical, should it plot to pdf?

filename

String with filename and desired path, end with .pdf

width, height

Width and height for pdf, see pdf().

useDingbats

Logical. Default is FALSE, compared to in default pdf().

Details

The x list needs to include at least the element MFI = assay mfi,

SAMPLES = Sample info. See below for required columns.

The SAMPLES element needs at least the columns:

"sample_name" with sample names, preferably LIMS-IDs, where replicates (named with one of pool|rep|mix|commercial)

"AssayNum" with assay number (vector with 1s if only one assay),

Note: The function plots to a layout, number of areas depending on number of different replicates and assays.


cekehe/rappp documentation built on May 17, 2022, 8:54 a.m.