ap_scoring2: Scoring

View source: R/data_transformation_2_diff_input.R

ap_scoring2R Documentation

Scoring

Description

Binning of MADs values in Autoimmunity Profiling.

Usage

ap_scoring2(
  x,
  MADlimits = seq(0, 70, 5),
  rightmost.closed = FALSE,
  left.open = FALSE,
  all.inside = FALSE,
  check.names = FALSE
)

Arguments

x

List with at least one element, see Details for naming and content. It is recommended to use the the output from ap_mads2().

MADlimits

vector of MADs values used as boundaries for binning.

rightmost.closed, left.open, all.inside

logical, see findInterval() for details. Defaults result in scores for MADS ≥ cutoff, and any value below the lowest cutoff gets score 0.

check.names

logical, altered default from data.frame().

Details

The input values will be binned into discrete bins (scores).

The x list needs to include at least the element:

MADS = assay MADs,

Value

Updated input x with the new list elements

CUTOFF_KEY = Cutoff key as data.frame with cutoff values, scores and colors

SCORE = scored data


cekehe/rappp documentation built on May 17, 2022, 8:54 a.m.