| ap_textplot | R Documentation |
This function displays text output in a graphics window. It is the equivalent of 'print' except that the output is displayed as a plot.
ap_textplot(object, halign = "center", valign = "center", cex, cmar = 1.5, ...)
Based on textplot() with slightly altered code.
Altered code found onlne (https://gist.github.com/johncolby/1482973).
Additional alteration done by CH, including making working methods, see code.
The input should be one of classes matrix, data.frame, vectors longer than 1,
single character string, single integer or single numeric value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.