| pairs2 | R Documentation |
A matrix of scatterplots is produced.
Alternative version of pairs() (default S3 method) where all axes are on the bottom and left sides.
Argument information copied from pairs().
NB! Better functionality for layout alterations is in the works.
pairs2( x, labels, panel = points, ..., horInd = 1:nc, verInd = 1:nc, lower.panel = panel, upper.panel = panel, diag.panel = NULL, text.panel = textPanel, label.pos = 0.5 + has.diag/3, line.main = 3, cex.labels = NULL, font.labels = 1, row1attop = TRUE, gap = 1, log = "" )
x |
the coordinates of points given as numeric columns of a matrix or data frame.
Logical and factor columns are converted to numeric in the same way that
|
labels |
the names of the variables. |
panel |
|
... |
arguments to be passed to or from methods.
Also, graphical parameters ( |
horInd, verInd |
The (numerical) indices of the variables to be plotted on the horizontal and vertical axes respectively. |
lower.panel, upper.panel |
separate panel functions (or |
diag.panel |
optional |
text.panel |
optional |
label.pos |
y position of labels in the text panel. |
line.main |
if |
cex.labels, font.labels |
graphics parameters for the text panel. |
row1attop |
logical. Should the layout be matrix-like with row 1 at the top, or graph-like with row 1 at the bottom? The latter (non default) leads to a basically symmetric scatterplot matrix. |
gap |
distance between subplots, in margin lines. |
log |
a character string indicating if logarithmic axes are to be used, see
|
Please see pairs()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.