View source: R/data_transformation_2_diff_input.R
| ap_mads2 | R Documentation |
Sample based normalization to number of Median Absolute Deviations (MADs) from the median (or other quantile probability) for Autoimmunity profiling data.
ap_mads2( x, center_prob = 0.5, constant = 1, na.rm = TRUE, low = FALSE, high = FALSE, check.names = FALSE )
x |
list with at least two elements, see Details for naming and content. |
center_prob |
value in [0,1] passed to prob in |
constant |
constant for |
na.rm |
logical, indicating whether NA values should be stripped
before the computation proceeds. Altered default from
|
low |
if TRUE, compute the ‘lo-median’, i.e., for even sample size, do not average
the two middle values, but take the smaller one.(From |
high |
if TRUE, compute the ‘hi-median’, i.e., take the larger of the two middle values
for even sample size.(From |
check.names |
logical, altered default from |
The input values will be normalized per sample to the number of MADs from the median
using the algorithm MADs = (MFI - median )/MAD, where MAD is calculated using mad(constant=1).
The x list needs to include at least the elements:
MFI = assay mfi,
BEADS = Beads info, if any should be excluded then these should be annotated in a column called "Filtered". Any beads with no text (ie. "" or NA) or "NegControl" in such column will be included in the transformation.
Updated input x with the new list elements
MADS = assay MADs.
MADS_CENTER = used center probability, default 0.5 means median.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.