| ap_rep | R Documentation |
various plots in one PDF to assess the replicates and overall reproducibility.
ap_rep( x, iter = 500, shouldpdf = TRUE, filename = "replicates.pdf", width = 12, height = 12, useDingbats = FALSE )
x |
List with at least two elements, see Deatils for naming and content. |
iter |
How many times random samples should be iterated. |
shouldpdf |
Logical, should it plot to pdf? |
filename |
String with filename and desired path, end with .pdf |
width, height |
Width and height for pdf, see |
useDingbats |
Logical. Default is |
The x list needs to include at least the element MFI = assay mfi,
SAMPLES = Sample info. See below for required columns.
The SAMPLES element needs at least the columns:
"sample_name" with sample names, preferably LIMS-IDs, where replicates (named with one of pool|rep|mix|commercial)
"AssayNum" with assay number (vector with 1s if only one assay),
Note: The function plots to a layout, number of areas depending on number of different replicates and assays.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.