View source: R/data_transformation_2_diff_input.R
| ap_scoring2 | R Documentation |
Binning of MADs values in Autoimmunity Profiling.
ap_scoring2( x, MADlimits = seq(0, 70, 5), rightmost.closed = FALSE, left.open = FALSE, all.inside = FALSE, check.names = FALSE )
x |
List with at least one element, see Details for naming and content.
It is recommended to use the the output from |
MADlimits |
vector of MADs values used as boundaries for binning. |
rightmost.closed, left.open, all.inside |
logical, see |
check.names |
logical, altered default from |
The input values will be binned into discrete bins (scores).
The x list needs to include at least the element:
MADS = assay MADs,
Updated input x with the new list elements
CUTOFF_KEY = Cutoff key as data.frame with cutoff values, scores and colors
SCORE = scored data
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.